@@ -2,6 +2,7 @@ import re
 
 import pytest
 from ape.exceptions import ContractLogicError
+from ethpm_types import ContractType
 from packaging.version import Version
 from vvm import compile_source  # type: ignore
 from vvm.exceptions import VyperError  # type: ignore
@@ -447,7 +448,7 @@ def test_trace_source_default_method(geth_provider, account, project):
     assert actual == expected
 
 
-def test_compile_with_version_set(config, projects_path, compiler, mocker):
+def test_compile_with_version_set_in_config(config, projects_path, compiler, mocker):
     path = projects_path / "version_in_config"
     version_from_config = "0.3.7"
     spy = mocker.patch("ape_vyper.compiler.vvm_compile_standard")
@@ -459,3 +460,25 @@ def test_compile_with_version_set(config, projects_path, compiler, mocker):
         # Show it uses this version in the compiler.
         project.load_contracts(use_cache=False)
         assert str(spy.call_args[1]["vyper_version"]) == version_from_config
+
+
+def test_compile_code(compiler, dev_revert_source):
+    code = dev_revert_source.read_text()
+    actual = compiler.compile_code(code, contractName="MyContract")
+    assert isinstance(actual, ContractType)
+    assert actual.name == "MyContract"
+    assert len(actual.abi) > 1
+    assert len(actual.deployment_bytecode.bytecode) > 1
+    assert len(actual.runtime_bytecode.bytecode) > 1
+
+
+def test_compile_with_version_set_in_settings_dict(config, compiler_manager, projects_path):
+    path = projects_path / "version_in_config"
+    contract = path / "contracts" / "v_contract.vy"
+
+    with config.using_project(path):
+        expected = (
+            '.*Version specification "0.3.10" is not compatible with compiler version "0.3.3"'
+        )
+        with pytest.raises(VyperCompileError, match=expected):
+            compiler_manager.compile([contract], settings={"version": "0.3.3"})
